//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI;

import java.io.*;
import java.awt.*;
import javax.swing.*;

/**
 *	And help dialog for helping people
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class Help extends JDialog
{
	/**
	 *	The text pane
	 */
	private JTextPane textpane;
	
	/**
	 *	Build the manual
	 *
	 *	@param title		the title of the box
	 *	@param filename		the name of the page (html, utf-8)
	 */
	public Help(String title, String filename)
	{
		super();
		
		setTitle(title);
		
		textpane = new JTextPane();
		textpane.setEditable(false);
		textpane.setContentType("text/html; charset=UTF-8");
		
		loadManual(filename);
		
		JScrollPane scroll = new JScrollPane(textpane);
		scroll.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
		
		getContentPane().add(new JScrollPane(textpane));
		
		pack();
		setSize(400,500);
		textpane.scrollToReference("top");
		centerScreen();
		setVisible(true);
	}
	
	/**
	 *	Load the file into the text area
	 */
	private void loadManual(String filename)
	{
		try
		{
			BufferedReader in = new BufferedReader(new FileReader(filename));
			
			String file = "";
			String text;
			while((text = in.readLine()) != null)
			{
				file += text;
			}
			
			textpane.setText(file);
		}
		catch (Exception e)
		{
			textpane.setText("Attempted to read a bad URL: " + filename);
		}
		//textpane.setText("<html><body>Hello World</body></html>");
	}
	

	/**
	 *	Center the dialog on the screen
	 */
	public void centerScreen()
	{
		Dimension dim = getToolkit().getScreenSize();
		Rectangle abounds = getBounds();
		setLocation(
			(dim.width - abounds.width) / 2,
			(dim.height - abounds.height) / 2
		);
	}
}