//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import ch.hearc.I04_05s08.GUI.SimpleDialog;
import ch.hearc.I04_05s08.GUI.SimpleFileFilter;
import javax.swing.*;
import java.awt.*;

/**
 *	The dialogbox for Rdf File (extended menu)
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public abstract class RdfFileDialog extends SimpleDialog
{
	/**
	 *	list of rdfs
	 */
	private JList rdfslist;
	
	/**
	 *	list model
	 */
	private DefaultListModel listmodel;
	
	/**
	 *	the manager
	 */
	private RdfGraphManager manager;
	
	/**
	 *	Top panel
	 */
	private JPanel top;
	
	/**
	 *	browse button
	 */
	private JButton browse;
	
	/**
	 *	Delete button
	 */
	private JButton delete;

	/**
	 *	The RDF Schemas
	 */
	private String files;
	
	/**
	 *	File chooser
	 */
	private JFileChooser filechooser;
	
	/**
	 *	Build a rdf file dialog
	 *
	 *	@param title		the title
	 *	@param manager		the RDF manager
	 */
	public RdfFileDialog(String title, RdfGraphManager manager)
	{
		super(title);
		
		this.manager = manager;
		
		JPanel toppanel = super.getTopPanel();
		
		Box vbox = Box.createVerticalBox();
		Box hbox = Box.createHorizontalBox();
		
		top = new JPanel();
		
		vbox.add(top);
		vbox.add(hbox);

		listmodel = new DefaultListModel();
		rdfslist = new JList(listmodel);
		rdfslist.setVisibleRowCount(5);
		
		delete = new JButton("delete");
		browse = new JButton("browse");
		
		delete.addActionListener(new RdfFileDialogDeleteListener(this));
		browse.addActionListener(new RdfFileDialogBrowseListener(this));
		
		hbox.add(delete);
		hbox.add(Box.createHorizontalGlue());
		hbox.add(browse);
		
		toppanel.setLayout(new BorderLayout());
		toppanel.add(vbox, BorderLayout.NORTH);
		toppanel.add(new JScrollPane(rdfslist));
		
		// file chooser
		filechooser = new JFileChooser();
		
		SimpleFileFilter filter = new SimpleFileFilter();
		filter.addExtension("rdf");
		filter.addExtension("rdfs");
		filter.addExtension("xml");
		filter.setDescription("RDF Schema");
		filechooser.setFileFilter(filter);
		
		// buttons
		getModifyButton().addActionListener(new RdfDialogModifyListener(this));
		getCancelButton().addActionListener(new RdfDialogCancelListener(this));
	}
	
	/**
	 *	Get the panel for the file form
	 *
	 *	@return the panel
	 */
	public JPanel getTopPanel()
	{
		return top;
	}
	
	/**
	 *	Get the listmodel
	 *
	 *	@return list model
	 */
	public DefaultListModel getListModel()
	{
		return listmodel;
	}
	
	/**
	 *	Get the list
	 *
	 *	@return list
	 */
	public JList getList()
	{
		return rdfslist;
	}
	
	/**
	 *	Get the manager
	 *
	 *	@return the Rdf manager
	 */
	public RdfGraphManager getManager()
	{
		return manager;
	}
	
	/**
	 *	Choose a RDF Schema to add
	 */
	public void choose()
	{
		int returnVal = filechooser.showOpenDialog(manager.getMainFrame());
		
		if(returnVal == JFileChooser.APPROVE_OPTION)
		{
			String file = filechooser.getSelectedFile().getPath();
			files += "|" +file;
			getListModel().addElement(file);
		}
	}
}