//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import ch.hearc.I04_05s08.GUI.Graph.*;
import ch.hearc.I04_05s08.Ontology.RDF.InstanceOfClass;
import java.awt.geom.*;

/**
 *	A node for RDFS graph
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfLiteral extends RdfNode
{	
	/**
	 *	Build a literal rdf node
	 *
	 *	@param ioc		the instance of class
	 */
	public RdfLiteral(InstanceOfClass ioc)
	{
		super(ioc);
	}
	
	/**
	 *	Build a copy of literal node
	 *
	 *	@param rdfl		the element to copy
	 */
	public RdfLiteral(RdfLiteral rdfl)
	{
		super(rdfl);
	}
	
	//--
	
	/**
	 *	Return a clone
	 *	
	 *	@return the cone
	 */
	public Object clone()
	{
		return (Object)new RdfLiteral(this);
	}
	
	/**
	 *	Display a dialog box for this node
	 *
	 *	@param graph		the graph
	 */
	public void showDialog(GraphPanel graph)
	{
		super.showDialog(graph);
		
		if(graph instanceof RdfGraph)
		{
			new RdfDialog(this,(RdfGraph)graph);
		}
	}
}
