//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import javax.swing.tree.*;
import javax.swing.*;
import java.awt.*;
import ch.hearc.I04_05s08.Ontology.RDF.Instance;

/**
 *	A node of the RDF Toolbar that is a leaf
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfTreeLeaf extends RdfTreeNode
{
	/**
	 *	The icon
	 */
	private Icon icon;
	
	/**
	 *	The colors
	 */
	private Color[] colors;
	
	/**
	 *	Associated resource
	 */
	private Instance instance;
	
	/**
	 *	Init the tree node
	 *
	 *	@param title		the title of the node
	 *	@param help		help text
	 *	@param icon		the icon
	 */
	public RdfTreeLeaf(String title, String help, Icon icon)
	{
		super(title, help);
		
		this.icon = icon;
		colors = new Color[2];
	}
	
	/**
	 *	Build a leaf
	 *
	 *	@param instance		the instance
	 *	@param icon			the incon
	 */
	public RdfTreeLeaf(Instance instance, Icon icon)
	{
		this(instance.getShortName(), instance.getName(), icon);
		
		this.instance = instance;
	}
	
	/**
	 *	Init the tree node
	 *
	 *	@param title		the title of the node
	 *	@param icon		the icon
	 */
	public RdfTreeLeaf(String title, Icon icon)
	{
		this(title, null, icon);
	}
	
	/**
	 *	Init the tree node
	 *
	 *	@param title		the title of the node
	 *	@param help		help text
	 */
	public RdfTreeLeaf(String title, String help)
	{
		this(title, help, null);
	}
	
	/**
	 *	Get the icon
	 *
	 *	@return 	the icon
	 */
	public Icon getIcon()
	{
		return icon;
	}
	
	/**
	 *	Get the RDF Instance
	 *
	 *	@return 	the instance
	 */
	public Instance getInstance()
	{
		return instance;
	}
	
	/**
	 *	Set the background color
	 *
	 *	@param color		background color
	 */
	public void setBackgroundColor(Color color)
	{
		colors[0] = color;
	}
	
	/**
	 *	Set the foreground color
	 *
	 *	@param color		foreground color
	 */
	public void setForegroundColor(Color color)
	{
		colors[1] = color;
	}
	
	/**
	 *	Get the background color
	 *
	 *	@return background color
	 */
	public Color getBackgroundColor()
	{
		return colors[0];
	}
	
	/**
	 *	Get the foreground color
	 *
	 *	@return foreground color
	 */
	public Color getForegroundColor()
	{
		return colors[1];
	}
}
