//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import javax.swing.event.*;
import javax.swing.*;
import ch.hearc.I04_05s08.Ontology.RDFS.*;
import ch.hearc.I04_05s08.Ontology.RDF.*;
import ch.hearc.I04_05s08.GUI.Graph.Element;

/**
 *	A listener for the toolbar's buttons
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfTreeSelectionListener implements TreeSelectionListener
{
	/**
	 *	The rdfs graph
	 */
	private RdfGraph graph;
	
	/**
	 *	The tree
	 */
	private JTree tree;
	
	/**
	 *	Build the listener
	 *
	 *	@param tree			the tree
	 *	@param graph			the Rdf graph
	 */
	public RdfTreeSelectionListener(JTree tree, RdfGraph graph)
	{
		this.graph = graph;
		this.tree = tree;
	}
	
	/**
	 *	Change the mode and the drawing element of the graph
	 *
	 *	@param e			action event
	 */
	public void valueChanged(TreeSelectionEvent e)
	{
		RdfTreeNode source = (RdfTreeNode)tree.getLastSelectedPathComponent();
		
		if(source instanceof RdfTreeLeaf && graph != null)
		{
			Instance res = (Instance)((RdfTreeLeaf)source).getInstance();
			Element n;
			
			if(res instanceof InstanceOfClass)
			{
				graph.setMode(graph.NODE_MODE);
				InstanceOfClass ioc = (InstanceOfClass)((InstanceOfClass)res).clone();
				
				if(ioc.isLiteral())
					n = (RdfNode)new RdfLiteral(ioc);
				else
					n = (RdfNode)new RdfResource(ioc);
			}
			else
			{
				graph.setMode(graph.ARROW_MODE);
				n = new RdfArrow((InstanceOfProperty)((InstanceOfProperty)res).clone());
			}
			
			
			n.setBackgroundColor(((RdfTreeLeaf)source).getBackgroundColor());
			n.setForegroundColor(((RdfTreeLeaf)source).getForegroundColor());
			
			graph.setDrawingElement(n);
		}
	}
}
