//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDFS;

import ch.hearc.I04_05s08.Ontology.RDFS.*;
import java.awt.geom.*;
import java.awt.*;

/**
 *	The extend arrow between two RdfsNode
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfsRange extends RdfsArrow
{
	/**
	 *	Init the arrow
	 */
	public RdfsRange()
	{
		super("range", null, null);
	}
	
	/**
	 *	Init the arrow
	 *
	 *	@param from		RdfsNode from
	 *	@param to		RdfsNode to
	 */
	public RdfsRange(RdfsNode from, RdfsNode to)
	{
		this();
		setNodes(from, to);
	}
	
	/**
	 *	Clone me
	 *
	 *	@return the clone
	 */
	public Object clone()
	{
		return new RdfsRange((RdfsNode)getNodes()[0], (RdfsNode)getNodes()[1]);
	}
	
	/**
	 *	Set the nodes for the set of the range
	 *
	 *	@param from			the from node
	 *	@param to			the to node
	 *	@return if the nodes are valid (together)
	 */
	public boolean setNodes(RdfsNode from, RdfsNode to)
	{		
		//super.setNodes(from, to);
		
		if(from instanceof RdfsPropertyNode && to instanceof RdfsClassNode)
		{
			super.setNodes(from, to);
			
			RdfsProperty prop = (RdfsProperty)from.getResource();
			RdfsClass range = (RdfsClass)to.getResource();
			
			return prop.addRange(range);
		}
		else
		{
			return false;
		}
	}
	
	/**
	 *	Draw the  line and the arrow
	 *
	 *	@param g2d the graphic context
	 */
	public void drawLine(Graphics2D g2d)
	{
		super.drawLine(g2d);
		
		double r = 20;
		double angle = getAngle() ;
		
		Polygon arrow = new Polygon(
			new int[]{0, (int)(r* Math.cos(angle + Math.PI/6.)), (int)(r* Math.cos(angle - Math.PI/6.))},
			new int[]{0, (int)(r* Math.sin(angle + Math.PI/6.)), (int)(r* Math.sin(angle - Math.PI/6.))},
			3
		);
		
		// important for the contains()
		setArrow(arrow);
		
		arrow.translate((int)getLine().getP2().getX(), (int)getLine().getP2().getY());
		
		g2d.setColor(getForegroundColor());
		g2d.fill(arrow);
	}
	
	/**
	 *	Disconnect the sub and sup
	 */
	public boolean unconnect()
	{		
		RdfsProperty prop = (RdfsProperty)((RdfsPropertyNode)getNodes()[0]).getResource();
		RdfsClass range = (RdfsClass)((RdfsClassNode)getNodes()[1]).getResource();
		
		return prop.delRange(range);
	}
}
