//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI;

import javax.swing.*;
import java.awt.*;

/**
 *	A Simple Dialog
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public abstract class SimpleDialog extends JDialog
{
	/**
	 *	The button that commit the modifications
	 */
	private JButton modify;
	
	/**
	 *	The button to cancel any operation
	 */
	private JButton cancel;
	
	/**
	 *	The top panel
	 */
	private JPanel topPanel;

	/**
	 *	Build a new dialog
	 *
	 *	@param	title		The title of the dialog box
	 */
	public SimpleDialog(String title)
	{
		super();
		
		setTitle(title);
		setModal(true);

		centerScreen();
		
		modify = new JButton("modify");
		cancel = new JButton("cancel");
		
		topPanel = new JPanel();
		
		//Box vbox = Box.createVerticalBox();
		Box hbox = Box.createHorizontalBox();
		
		hbox.add(cancel);
		hbox.add(Box.createGlue());
		hbox.add(modify);
		
		//vbox.add();
		//vbox.add(hbox);
		//vbox.add(Box.createGlue());
		
		getRootPane().setDefaultButton(modify);
		getContentPane().add(new JScrollPane(topPanel));
		getContentPane().add(hbox, BorderLayout.SOUTH);
	}
	
	/**
	 *	Center the dialog on the screen
	 */
	public void centerScreen()
	{
		Dimension dim = getToolkit().getScreenSize();
		Rectangle abounds = getBounds();
		setLocation(
			(dim.width - abounds.width) / 2,
			(dim.height - abounds.height) / 2
		);
	}
	
	/**
	 *	Get the panel on the top of the dialog
	 *
	 *	@return the panel on the top
	 */
	public JPanel getTopPanel()
	{
		return topPanel;
	}
	
	/**
	 *	Get the button that is labelled modify
	 *
	 *	@return the button "modify"
	 */
	public JButton getModifyButton()
	{
		return modify;
	}
	
	/**
	 *	Get the button that is labelled cancel
	 *
	 *	@return the button "cancel"
	 */
	public JButton getCancelButton()
	{
		return cancel;
	}
	
	/**
	 *	Closing the window, but how ?
	 */
	public void close()
	{
		hide();
	}
	
	/**
	 *	Apply the values
	 */
	public abstract void apply();
}
