//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.Ontology;

import ch.hearc.I04_05s08.Ontology.RDFS.*;
import ch.hearc.I04_05s08.Ontology.RDF.*;

/**
 *	A library to build RDF(S)
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class OntManager
{		
	/**
	 *	Save a Rdf file
	 *
	 *	@param filename		path of the output
	 *	@param file			rdf file
	 *	@return the state of the operation 
	 */
	public static boolean saveRdf(String filename, RdfFile file)
	{
		return RdfManager.saveRdf(filename, file);
	}
	
	/**
	 *	Open a RDF file without RDF Schemas
	 *
	 *	@param filename		path of the file
	 *	@return				RDF File
	 */
	public static RdfFile openRdf(String filename)
	{
		return RdfManager.openRdf(filename, null);
	}
	
	/**
	 *	Open a RDF file with RDF Schemas
	 *
	 *	@param filename		path of the file
	 *	@param rdfs			RDF Schemas (null for not)
	 *	@return				RDF File
	 */
	public static RdfFile openRdf(String filename, RdfsFile[] rdfs)
	{
		return RdfManager.openRdf(filename,rdfs);
	}
	
	/**
	 *	Save a rdfs file
	 *
	 *	@param filename		path of the source file
	 *	@param file			the rdfs file
	 */
	public static boolean saveRdfs(String filename, RdfsFile file)
	{
		return RdfsManager.saveRdfs(filename,file);
	}
	
	/**
	 *	Build a rdfs file
	 *
	 *	@param filename		path of the source file
	 *	@return				the rdfs file
	 */
	public static RdfsFile openRdfs(String filename)
	{
		return RdfsManager.openRdfs(filename);
	}
}
